@@ -140,6 +140,8 @@ Group by StressVowel) AS averages""",[self.pk])
             if str(w.Dialog) == 's2003' or str(w.Dialog) =='s4001':
                 continue
             allout.extend(w.getAnalysisLines(form))
+            if settings.DEBUG:
+                print outline[-1]
         return allout
 
     def load_dialogs(self):
